@@ -130,7 +130,7 @@ def upload_loop():
                     ffmpeg
                     .input(name, format="h264", r=str(CAMERA_FRAMERATE))
                     .output(mp4_name, **{"format": "mp4", "c:v": "copy", "r": str(CAMERA_FRAMERATE)})
-                    .run(quiet=False)
+                    .run(quiet=False, overwrite_output=True)
                 )
                 logging.info('repackage took %s', (datetime.datetime.now() - start).total_seconds())
                 time.sleep(1)
